============
dicomtrolley
============

.. image:: https://github.com/sjoerdk/dicomtrolley/workflows/build/badge.svg
        :target: https://github.com/sjoerdk/dicomtrolley/actions?query=workflow%3Abuild
        :alt: Build Status


.. image:: https://img.shields.io/pypi/v/dicomtrolley.svg
        :target: https://pypi.python.org/pypi/dicomtrolley

.. image:: https://readthedocs.org/projects/dicomtrolley/badge/?version=latest
        :target: https://dicomtrolley.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status


.. image:: https://pyup.io/repos/github/sjoerdk/dicomtrolley/shield.svg
     :target: https://pyup.io/repos/github/sjoerdk/dicomtrolley/
     :alt: Updates



Retrieve medical images via DICOM-QR and DICOMweb


* Free software: GNU General Public License v3
* Documentation: https://dicomtrolley.readthedocs.io.


Features
--------

* TODO

Credits
-------

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage
